@@ -51,11 +51,11 @@ fn make() -> clap::Command {
                 "[--merge] <branch>",
                 "{--list,-l}",
                 "{--create,-c} <new-branch> [committish]",
-                "--clone [new-branch]",
+                "{--clone,-C} [new-branch]",
                 "{--rename,-r} [old-name] <new-name>",
                 "{--protect,-p} [branch]",
                 "{--unprotect,-u} [branch]",
-                "--delete [--force] <branch>",
+                "{--delete,-D} [--force] <branch>",
                 "--cleanup [--force] [branch]",
                 "{--describe,-d} <description> [branch]",
             ],
