@@ -9,7 +9,7 @@ use std::{
     path::Path,
 };
 
-use anyhow::{anyhow, Result};
+use anyhow::{anyhow, Context, Result};
 use bstr::BString;
 
 use super::description::{EditablePatchDescription, EditedPatchDescription};
@@ -89,22 +89,25 @@ pub(crate) fn call_editor<P: AsRef<Path>>(
             stderr.flush()?;
         }
 
-        let mut subcommand = OsString::new();
-        subcommand.push(&editor);
-        subcommand.push(" ");
-        subcommand.push(path.as_ref().as_os_str());
+        let status_result = gix_command::prepare(&editor)
+            .arg(path.as_ref())
+            .with_shell_allow_argument_splitting()
+            .stdout(std::process::Stdio::inherit())
+            .spawn()
+            .with_context(|| format!("running editor: {}", editor.to_string_lossy()))
+            .and_then(|mut child| {
+                child
+                    .wait()
+                    .with_context(|| format!("waiting editor: {}", editor.to_string_lossy()))
+            });
 
-        let shell = if cfg!(target_os = "windows") {
-            "sh"
-        } else {
-            "/bin/sh"
-        };
-        let mut child = std::process::Command::new(shell)
-            .arg("-c")
-            .arg(subcommand)
-            .spawn()?;
+        if use_advice && !is_dumb {
+            let mut stderr = std::io::stderr();
+            stderr.write_all("\r\x1b[K".as_bytes()).unwrap_or(());
+            stderr.flush()?;
+        }
 
-        let status = child.wait()?;
+        let status = status_result?;
 
         if !status.success() {
             return Err(anyhow!(
@@ -112,12 +115,6 @@ pub(crate) fn call_editor<P: AsRef<Path>>(
                 editor.to_string_lossy()
             ));
         }
-
-        if use_advice && !is_dumb {
-            let mut stderr = std::io::stderr();
-            stderr.write_all("\r\x1b[K".as_bytes()).unwrap_or(());
-            stderr.flush()?;
-        }
     }
 
     let buf = std::fs::read(&path)?.into();
